@@ -3,6 +3,7 @@ package rule
 import (
 	"fmt"
 	"os"
+	"path/filepath"
 	runtimeDebug "runtime/debug"
 	"strings"
 
@@ -11,13 +12,12 @@ import (
 	"github.com/aquasecurity/tfsec/pkg/result"
 
 	"github.com/aquasecurity/tfsec/internal/app/tfsec/debug"
-	"github.com/aquasecurity/tfsec/internal/app/tfsec/hclcontext"
 
 	"github.com/aquasecurity/tfsec/internal/app/tfsec/block"
 )
 
 // CheckRule the provided HCL block against the rule
-func CheckRule(r *Rule, resourceBlock block.Block, ctx *hclcontext.Context, ignoreErrors bool) result.Set {
+func CheckRule(r *Rule, resourceBlock block.Block, module block.Module, ignoreErrors bool) result.Set {
 	if ignoreErrors {
 		defer func() {
 			if err := recover(); err != nil {
@@ -44,39 +44,32 @@ func CheckRule(r *Rule, resourceBlock block.Block, ctx *hclcontext.Context, igno
 		WithRuleProvider(r.Provider).
 		WithLinks(links)
 
-	r.CheckFunc(resultSet, resourceBlock, ctx)
+	r.CheckFunc(resultSet, resourceBlock, module)
 	return resultSet
 }
 
 // IsRuleRequiredForBlock returns true if the Rule should be applied to the given HCL block
-func IsRuleRequiredForBlock(rule *Rule, block block.Block) bool {
+func IsRuleRequiredForBlock(rule *Rule, b block.Block) bool {
 
 	if rule.CheckFunc == nil {
 		return false
 	}
 
 	if len(rule.RequiredTypes) > 0 {
-		var found bool
-		for _, requiredType := range rule.RequiredTypes {
-			if block.Type() == requiredType {
-				found = true
-				break
-			}
-		}
-		if !found {
+		if !checkRequiredTypesMatch(rule, b) {
 			return false
 		}
 	}
 
 	if len(rule.RequiredLabels) > 0 {
-		var found bool
-		for _, requiredLabel := range rule.RequiredLabels {
-			if requiredLabel == "*" || (len(block.Labels()) > 0 && wildcardMatch(requiredLabel, block.TypeLabel())) {
-				found = true
-				break
-			}
+		if !checkRequiredLabelsMatch(rule, b) {
+			return false
 		}
-		if !found {
+
+	}
+
+	if len(rule.RequiredSources) > 0 && b.Type() == block.TypeModule.Name() {
+		if !checkRequiredSourcesMatch(rule, b) {
 			return false
 		}
 	}
@@ -84,6 +77,75 @@ func IsRuleRequiredForBlock(rule *Rule, block block.Block) bool {
 	return true
 }
 
+func checkRequiredTypesMatch(rule *Rule, b block.Block) bool {
+	var found bool
+	for _, requiredType := range rule.RequiredTypes {
+		if b.Type() == requiredType {
+			found = true
+			break
+		}
+	}
+
+	return found
+}
+
+func checkRequiredLabelsMatch(rule *Rule, b block.Block) bool {
+	var found bool
+	for _, requiredLabel := range rule.RequiredLabels {
+		if requiredLabel == "*" || (len(b.Labels()) > 0 && wildcardMatch(requiredLabel, b.TypeLabel())) {
+			found = true
+			break
+		}
+	}
+
+	return found
+}
+
+func checkRequiredSourcesMatch(rule *Rule, b block.Block) bool {
+	var found bool
+	if sourceAttr := b.GetAttribute("source"); sourceAttr.IsNotNil() {
+		sourcePath := sourceAttr.ValueAsStrings()[0]
+
+		// resolve module source path to path relative to cwd
+		if strings.HasPrefix(sourcePath, ".") {
+			var err error
+			sourcePath, err = cleanPathRelativeToWorkingDir(filepath.Dir(b.Range().Filename), sourcePath)
+			if err != nil {
+				_, _ = fmt.Fprintf(os.Stderr, "WARNING: did not path for module %s due to error(s): %s\n", fmt.Sprintf("%s:%s", b.FullName(), b.Range().Filename), err)
+			}
+		}
+
+		for _, requiredSource := range rule.RequiredSources {
+			if requiredSource == "*" || wildcardMatch(requiredSource, sourcePath) {
+				found = true
+				break
+			}
+		}
+	}
+
+	return found
+}
+
+func cleanPathRelativeToWorkingDir(dir, path string) (string, error) {
+	absPath := filepath.Clean(filepath.Join(dir, path))
+
+	wDir, err := os.Getwd()
+	if err != nil {
+		return "", err
+	}
+
+	if !strings.HasSuffix(wDir, "/") {
+		wDir = filepath.Join(wDir, "/")
+	}
+
+	relPath, err := filepath.Rel(wDir, absPath)
+	if err != nil {
+		return "", err
+	}
+
+	return relPath, nil
+}
+
 func wildcardMatch(pattern string, subject string) bool {
 	if pattern == "" {
 		return false
